/* optcc.h
 * Header file for C-style interface to the OPT library
 * generated by apiwrapper for GAMS Version 33.2.0
 *
 * GAMS - Loading mechanism for GAMS Expert-Level APIs
 *
 * Copyright (c) 2016-2020 GAMS Software GmbH <support@gams.com>
 * Copyright (c) 2016-2020 GAMS Development Corp. <support@gams.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#if ! defined(_OPTCC_H_)
#     define  _OPTCC_H_

#define OPTAPIVERSION 4



enum optDataType {
  optDataNone    = 0,
  optDataInteger = 1,
  optDataDouble  = 2,
  optDataString  = 3,
  optDataStrList = 4  };

enum optOptionType {
  optTypeInteger   = 0,
  optTypeDouble    = 1,
  optTypeString    = 2,
  optTypeBoolean   = 3,
  optTypeEnumStr   = 4,
  optTypeEnumInt   = 5,
  optTypeMultiList = 6,
  optTypeStrList   = 7,
  optTypeMacro     = 8,
  optTypeImmediate = 9  };

enum optOptionSubType {
  optsubRequired = 0,
  optsubNoValue  = 1,
  optsubOptional = 2,
  optsub2Values  = 3  };

enum optMsgType {
  optMsgInputEcho    = 0,
  optMsgHelp         = 1,
  optMsgDefineError  = 2,
  optMsgValueError   = 3,
  optMsgValueWarning = 4,
  optMsgDeprecated   = 5,
  optMsgFileEnter    = 6,
  optMsgFileLeave    = 7,
  optMsgTooManyMsgs  = 8,
  optMsgUserError    = 9  };

enum optVarEquMapType {
  optMapIndicator  = 0,
  optMapDefinedVar = 1  };


#if defined(_WIN32)
# define OPT_CALLCONV __stdcall
#else
# define OPT_CALLCONV
#endif

#if defined(__cplusplus)
extern "C" {
#endif

struct optRec;
typedef struct optRec *optHandle_t;

typedef int (*optErrorCallback_t) (int ErrCount, const char *msg);

/* headers for "wrapper" routines implemented in C */
int optGetReady  (char *msgBuf, int msgBufLen);
int optGetReadyD (const char *dirName, char *msgBuf, int msgBufLen);
int optGetReadyL (const char *libName, char *msgBuf, int msgBufLen);
int optCreate    (optHandle_t *popt, char *msgBuf, int msgBufLen);
int optCreateD   (optHandle_t *popt, const char *dirName, char *msgBuf, int msgBufLen);
int optCreateL   (optHandle_t *popt, const char *libName, char *msgBuf, int msgBufLen);
int optFree      (optHandle_t *popt);

int optLibraryLoaded(void);
int optLibraryUnload(void);

/* returns true  (1) if API and library have the same version,
           false (0) on failure;
   Library needs to be initialized before calling this        */
int  optCorrectLibraryVersion(char *msgBuf, int msgBufLen);

int  optGetScreenIndicator   (void);
void optSetScreenIndicator   (int scrind);
int  optGetExceptionIndicator(void);
void optSetExceptionIndicator(int excind);
int  optGetExitIndicator     (void);
void optSetExitIndicator     (int extind);
optErrorCallback_t optGetErrorCallback(void);
void optSetErrorCallback(optErrorCallback_t func);
int  optGetAPIErrorCount     (void);
void optSetAPIErrorCount     (int ecnt);

void optErrorHandling(const char *msg);
void optInitMutexes(void);
void optFiniMutexes(void);


#if defined(OPT_MAIN)    /* we must define some things only once */
# define OPT_FUNCPTR(NAME)  NAME##_t NAME = NULL
#else
# define OPT_FUNCPTR(NAME)  extern NAME##_t NAME
#endif

/* function typedefs and pointer definitions */

typedef int (OPT_CALLCONV *TArgvCB_t) (char *argv, int *idx);

/* Prototypes for Dummy Functions */
int  OPT_CALLCONV d_optReadDefinition (optHandle_t popt, const char *fn);
int  OPT_CALLCONV d_optReadDefinitionFromPChar (optHandle_t popt, char *p);
int  OPT_CALLCONV d_optReadParameterFile (optHandle_t popt, const char *fn);
void  OPT_CALLCONV d_optReadFromStr (optHandle_t popt, const char *s);
int  OPT_CALLCONV d_optWriteParameterFile (optHandle_t popt, const char *fn);
void  OPT_CALLCONV d_optClearMessages (optHandle_t popt);
void  OPT_CALLCONV d_optAddMessage (optHandle_t popt, const char *info);
void  OPT_CALLCONV d_optGetMessage (optHandle_t popt, int NrMsg, char *info, int *iType);
void  OPT_CALLCONV d_optResetAll (optHandle_t popt);
void  OPT_CALLCONV d_optResetAllRecent (optHandle_t popt);
void  OPT_CALLCONV d_optResetRecentChanges (optHandle_t popt);
void  OPT_CALLCONV d_optShowHelp (optHandle_t popt, const char *AHlpID);
int  OPT_CALLCONV d_optResetNr (optHandle_t popt, int ANr);
int  OPT_CALLCONV d_optFindStr (optHandle_t popt, const char *AName, int *ANr, int *ARefNr);
int  OPT_CALLCONV d_optGetInfoNr (optHandle_t popt, int ANr, int *ADefined, int *ADefinedR, int *ARefNr, int *ADataType, int *AOptType, int *ASubType);
int  OPT_CALLCONV d_optGetValuesNr (optHandle_t popt, int ANr, char *ASName, int *AIVal, double *ADVal, char *ASVal);
int  OPT_CALLCONV d_optSetValuesNr (optHandle_t popt, int ANr, int AIVal, double ADVal, const char *ASVal);
int  OPT_CALLCONV d_optSetValues2Nr (optHandle_t popt, int ANr, int AIVal, double ADVal, const char *ASVal);
void  OPT_CALLCONV d_optVersion (optHandle_t popt, char *sversion);
void  OPT_CALLCONV d_optDefinitionFile (optHandle_t popt, char *sfilename);
int  OPT_CALLCONV d_optGetFromAnyStrList (optHandle_t popt, int idash, char *skey, char *sval);
int  OPT_CALLCONV d_optGetFromListStr (optHandle_t popt, const char *skey, char *sval);
int  OPT_CALLCONV d_optListCountStr (optHandle_t popt, const char *skey);
int  OPT_CALLCONV d_optReadFromListStr (optHandle_t popt, const char *skey, int iPos, char *sval);
int  OPT_CALLCONV d_optSynonymCount (optHandle_t popt);
int  OPT_CALLCONV d_optGetSynonym (optHandle_t popt, int NrSyn, char *SSyn, char *SName);
void  OPT_CALLCONV d_optEchoSet (optHandle_t popt, int AIVal);
int  OPT_CALLCONV d_optEOLOnlySet (optHandle_t popt, int AIVal);
void  OPT_CALLCONV d_optNoBoundsSet (optHandle_t popt, int AIVal);
int  OPT_CALLCONV d_optEOLChars (optHandle_t popt, char *EOLChars);
void  OPT_CALLCONV d_optErrorCount (optHandle_t popt, int *iErrors, int *iWarnings);
int  OPT_CALLCONV d_optGetBoundsInt (optHandle_t popt, int ANr, int *ilval, int *ihval, int *idval);
int  OPT_CALLCONV d_optGetBoundsDbl (optHandle_t popt, int ANr, double *dlval, double *dhval, double *ddval);
int  OPT_CALLCONV d_optGetDefaultStr (optHandle_t popt, int ANr, char *sval);
int  OPT_CALLCONV d_optGetIntNr (optHandle_t popt, int ANr, int *AIVal);
int  OPT_CALLCONV d_optGetInt2Nr (optHandle_t popt, int ANr, int *AIVal);
int  OPT_CALLCONV d_optSetIntNr (optHandle_t popt, int ANr, int AIVal);
int  OPT_CALLCONV d_optSetInt2Nr (optHandle_t popt, int ANr, int AIVal);
int  OPT_CALLCONV d_optGetStrNr (optHandle_t popt, int ANr, char *ASVal);
int  OPT_CALLCONV d_optGetOptHelpNr (optHandle_t popt, int ANr, char *AName, int *AHc, int *AGroup);
int  OPT_CALLCONV d_optGetEnumHelp (optHandle_t popt, int ANr, int AOrd, int *AHc, char *AHelpStr);
int  OPT_CALLCONV d_optGetEnumStrNr (optHandle_t popt, int ANr, char *ASVal, int *AOrd);
int  OPT_CALLCONV d_optGetEnumCount (optHandle_t popt, int ANr, int *ACount);
int  OPT_CALLCONV d_optGetEnumValue (optHandle_t popt, int ANr, int AOrd, int *AValInt, char *AValStr);
int  OPT_CALLCONV d_optGetStr2Nr (optHandle_t popt, int ANr, char *ASVal);
int  OPT_CALLCONV d_optSetStrNr (optHandle_t popt, int ANr, const char *ASVal);
int  OPT_CALLCONV d_optSetStr2Nr (optHandle_t popt, int ANr, const char *ASVal);
int  OPT_CALLCONV d_optGetDblNr (optHandle_t popt, int ANr, double *ADVal);
int  OPT_CALLCONV d_optGetDbl2Nr (optHandle_t popt, int ANr, double *ADVal);
int  OPT_CALLCONV d_optSetDblNr (optHandle_t popt, int ANr, double ADVal);
int  OPT_CALLCONV d_optSetDbl2Nr (optHandle_t popt, int ANr, double ADVal);
int  OPT_CALLCONV d_optGetValStr (optHandle_t popt, const char *AName, char *ASVal);
int  OPT_CALLCONV d_optGetVal2Str (optHandle_t popt, const char *AName, char *ASVal);
int  OPT_CALLCONV d_optGetNameNr (optHandle_t popt, int ANr, char *ASName);
int  OPT_CALLCONV d_optGetDefinedNr (optHandle_t popt, int ANr, int *AIVal);
int  OPT_CALLCONV d_optGetHelpNr (optHandle_t popt, int ANr, char *ASOpt, char *ASHelp);
int  OPT_CALLCONV d_optGetGroupNr (optHandle_t popt, int ANr, char *AName, int *AGroup, int *AHc, char *AHelp);
int  OPT_CALLCONV d_optGetGroupGrpNr (optHandle_t popt, int AGroup);
int  OPT_CALLCONV d_optGetOptGroupNr (optHandle_t popt, int ANr);
int  OPT_CALLCONV d_optGetDotOptNr (optHandle_t popt, int ANr, char *VEName, int *AObjNr, int *ADim, double *AValue);
int  OPT_CALLCONV d_optGetDotOptUel (optHandle_t popt, int ANr, int ADim, char *AUEL);
int  OPT_CALLCONV d_optGetVarEquMapNr (optHandle_t popt, int maptype, int ANr, char *EquName, char *VarName, int *EquDim, int *VarDim, int *AValue);
int  OPT_CALLCONV d_optGetEquVarEquMapNr (optHandle_t popt, int maptype, int ANr, int ADim, char *AIndex);
int  OPT_CALLCONV d_optGetVarVarEquMapNr (optHandle_t popt, int maptype, int ANr, int ADim, char *AIndex);
int  OPT_CALLCONV d_optVarEquMapCount (optHandle_t popt, int maptype, int *ANrErrors);
int  OPT_CALLCONV d_optGetIndicatorNr (optHandle_t popt, int ANr, char *EquName, char *VarName, int *EquDim, int *VarDim, int *AValue);
int  OPT_CALLCONV d_optGetEquIndicatorNr (optHandle_t popt, int ANr, int ADim, char *AIndex);
int  OPT_CALLCONV d_optGetVarIndicatorNr (optHandle_t popt, int ANr, int ADim, char *AIndex);
int  OPT_CALLCONV d_optIndicatorCount (optHandle_t popt, int *ANrErrors);
int  OPT_CALLCONV d_optDotOptCount (optHandle_t popt, int *ANrErrors);
int  OPT_CALLCONV d_optSetRefNr (optHandle_t popt, int ANr, int ARefNr);
int  OPT_CALLCONV d_optSetRefNrStr (optHandle_t popt, const char *AOpt, int ARefNr);
int  OPT_CALLCONV d_optGetConstName (optHandle_t popt, int cgroup, int cindex, char *cname);
int  OPT_CALLCONV d_optGetTypeName (optHandle_t popt, int TNr, char *sTName);
int  OPT_CALLCONV d_optLookUp (optHandle_t popt, const char *AOpt);
void  OPT_CALLCONV d_optReadFromPChar (optHandle_t popt, char *p);
void  OPT_CALLCONV d_optReadFromCmdLine (optHandle_t popt, char *p);
void  OPT_CALLCONV d_optReadFromCmdArgs (optHandle_t popt, TArgvCB_t cb);
int  OPT_CALLCONV d_optGetNameOpt (optHandle_t popt, const char *ASVal, char *solver, int *opt);
int  OPT_CALLCONV d_optResetStr (optHandle_t popt, const char *AName);
int  OPT_CALLCONV d_optGetDefinedStr (optHandle_t popt, const char *AName);
int  OPT_CALLCONV d_optGetIntStr (optHandle_t popt, const char *AName);
double  OPT_CALLCONV d_optGetDblStr (optHandle_t popt, const char *AName);
char * OPT_CALLCONV d_optGetStrStr (optHandle_t popt, const char *AName, char *buf);
void  OPT_CALLCONV d_optSetIntStr (optHandle_t popt, const char *AName, int AIVal);
void  OPT_CALLCONV d_optSetDblStr (optHandle_t popt, const char *AName, double ADVal);
void  OPT_CALLCONV d_optSetStrStr (optHandle_t popt, const char *AName, const char *ASVal);
int  OPT_CALLCONV d_optIsDeprecated (optHandle_t popt, const char *AName);
int  OPT_CALLCONV d_optCount (optHandle_t popt);
int  OPT_CALLCONV d_optMessageCount (optHandle_t popt);
int  OPT_CALLCONV d_optGroupCount (optHandle_t popt);
int  OPT_CALLCONV d_optRecentEnabled (optHandle_t popt);
void OPT_CALLCONV d_optRecentEnabledSet (optHandle_t popt, const int x);
char * OPT_CALLCONV d_optSeparator (optHandle_t popt, char *buf);
char * OPT_CALLCONV d_optStringQuote (optHandle_t popt, char *buf);

typedef int  (OPT_CALLCONV *optReadDefinition_t) (optHandle_t popt, const char *fn);
OPT_FUNCPTR(optReadDefinition);
typedef int  (OPT_CALLCONV *optReadDefinitionFromPChar_t) (optHandle_t popt, char *p);
OPT_FUNCPTR(optReadDefinitionFromPChar);
typedef int  (OPT_CALLCONV *optReadParameterFile_t) (optHandle_t popt, const char *fn);
OPT_FUNCPTR(optReadParameterFile);
typedef void  (OPT_CALLCONV *optReadFromStr_t) (optHandle_t popt, const char *s);
OPT_FUNCPTR(optReadFromStr);
typedef int  (OPT_CALLCONV *optWriteParameterFile_t) (optHandle_t popt, const char *fn);
OPT_FUNCPTR(optWriteParameterFile);
typedef void  (OPT_CALLCONV *optClearMessages_t) (optHandle_t popt);
OPT_FUNCPTR(optClearMessages);
typedef void  (OPT_CALLCONV *optAddMessage_t) (optHandle_t popt, const char *info);
OPT_FUNCPTR(optAddMessage);
typedef void  (OPT_CALLCONV *optGetMessage_t) (optHandle_t popt, int NrMsg, char *info, int *iType);
OPT_FUNCPTR(optGetMessage);
typedef void  (OPT_CALLCONV *optResetAll_t) (optHandle_t popt);
OPT_FUNCPTR(optResetAll);
typedef void  (OPT_CALLCONV *optResetAllRecent_t) (optHandle_t popt);
OPT_FUNCPTR(optResetAllRecent);
typedef void  (OPT_CALLCONV *optResetRecentChanges_t) (optHandle_t popt);
OPT_FUNCPTR(optResetRecentChanges);
typedef void  (OPT_CALLCONV *optShowHelp_t) (optHandle_t popt, const char *AHlpID);
OPT_FUNCPTR(optShowHelp);
typedef int  (OPT_CALLCONV *optResetNr_t) (optHandle_t popt, int ANr);
OPT_FUNCPTR(optResetNr);
typedef int  (OPT_CALLCONV *optFindStr_t) (optHandle_t popt, const char *AName, int *ANr, int *ARefNr);
OPT_FUNCPTR(optFindStr);
typedef int  (OPT_CALLCONV *optGetInfoNr_t) (optHandle_t popt, int ANr, int *ADefined, int *ADefinedR, int *ARefNr, int *ADataType, int *AOptType, int *ASubType);
OPT_FUNCPTR(optGetInfoNr);
typedef int  (OPT_CALLCONV *optGetValuesNr_t) (optHandle_t popt, int ANr, char *ASName, int *AIVal, double *ADVal, char *ASVal);
OPT_FUNCPTR(optGetValuesNr);
typedef int  (OPT_CALLCONV *optSetValuesNr_t) (optHandle_t popt, int ANr, int AIVal, double ADVal, const char *ASVal);
OPT_FUNCPTR(optSetValuesNr);
typedef int  (OPT_CALLCONV *optSetValues2Nr_t) (optHandle_t popt, int ANr, int AIVal, double ADVal, const char *ASVal);
OPT_FUNCPTR(optSetValues2Nr);
typedef void  (OPT_CALLCONV *optVersion_t) (optHandle_t popt, char *sversion);
OPT_FUNCPTR(optVersion);
typedef void  (OPT_CALLCONV *optDefinitionFile_t) (optHandle_t popt, char *sfilename);
OPT_FUNCPTR(optDefinitionFile);
typedef int  (OPT_CALLCONV *optGetFromAnyStrList_t) (optHandle_t popt, int idash, char *skey, char *sval);
OPT_FUNCPTR(optGetFromAnyStrList);
typedef int  (OPT_CALLCONV *optGetFromListStr_t) (optHandle_t popt, const char *skey, char *sval);
OPT_FUNCPTR(optGetFromListStr);
typedef int  (OPT_CALLCONV *optListCountStr_t) (optHandle_t popt, const char *skey);
OPT_FUNCPTR(optListCountStr);
typedef int  (OPT_CALLCONV *optReadFromListStr_t) (optHandle_t popt, const char *skey, int iPos, char *sval);
OPT_FUNCPTR(optReadFromListStr);
typedef int  (OPT_CALLCONV *optSynonymCount_t) (optHandle_t popt);
OPT_FUNCPTR(optSynonymCount);
typedef int  (OPT_CALLCONV *optGetSynonym_t) (optHandle_t popt, int NrSyn, char *SSyn, char *SName);
OPT_FUNCPTR(optGetSynonym);
typedef void  (OPT_CALLCONV *optEchoSet_t) (optHandle_t popt, int AIVal);
OPT_FUNCPTR(optEchoSet);
typedef int  (OPT_CALLCONV *optEOLOnlySet_t) (optHandle_t popt, int AIVal);
OPT_FUNCPTR(optEOLOnlySet);
typedef void  (OPT_CALLCONV *optNoBoundsSet_t) (optHandle_t popt, int AIVal);
OPT_FUNCPTR(optNoBoundsSet);
typedef int  (OPT_CALLCONV *optEOLChars_t) (optHandle_t popt, char *EOLChars);
OPT_FUNCPTR(optEOLChars);
typedef void  (OPT_CALLCONV *optErrorCount_t) (optHandle_t popt, int *iErrors, int *iWarnings);
OPT_FUNCPTR(optErrorCount);
typedef int  (OPT_CALLCONV *optGetBoundsInt_t) (optHandle_t popt, int ANr, int *ilval, int *ihval, int *idval);
OPT_FUNCPTR(optGetBoundsInt);
typedef int  (OPT_CALLCONV *optGetBoundsDbl_t) (optHandle_t popt, int ANr, double *dlval, double *dhval, double *ddval);
OPT_FUNCPTR(optGetBoundsDbl);
typedef int  (OPT_CALLCONV *optGetDefaultStr_t) (optHandle_t popt, int ANr, char *sval);
OPT_FUNCPTR(optGetDefaultStr);
typedef int  (OPT_CALLCONV *optGetIntNr_t) (optHandle_t popt, int ANr, int *AIVal);
OPT_FUNCPTR(optGetIntNr);
typedef int  (OPT_CALLCONV *optGetInt2Nr_t) (optHandle_t popt, int ANr, int *AIVal);
OPT_FUNCPTR(optGetInt2Nr);
typedef int  (OPT_CALLCONV *optSetIntNr_t) (optHandle_t popt, int ANr, int AIVal);
OPT_FUNCPTR(optSetIntNr);
typedef int  (OPT_CALLCONV *optSetInt2Nr_t) (optHandle_t popt, int ANr, int AIVal);
OPT_FUNCPTR(optSetInt2Nr);
typedef int  (OPT_CALLCONV *optGetStrNr_t) (optHandle_t popt, int ANr, char *ASVal);
OPT_FUNCPTR(optGetStrNr);
typedef int  (OPT_CALLCONV *optGetOptHelpNr_t) (optHandle_t popt, int ANr, char *AName, int *AHc, int *AGroup);
OPT_FUNCPTR(optGetOptHelpNr);
typedef int  (OPT_CALLCONV *optGetEnumHelp_t) (optHandle_t popt, int ANr, int AOrd, int *AHc, char *AHelpStr);
OPT_FUNCPTR(optGetEnumHelp);
typedef int  (OPT_CALLCONV *optGetEnumStrNr_t) (optHandle_t popt, int ANr, char *ASVal, int *AOrd);
OPT_FUNCPTR(optGetEnumStrNr);
typedef int  (OPT_CALLCONV *optGetEnumCount_t) (optHandle_t popt, int ANr, int *ACount);
OPT_FUNCPTR(optGetEnumCount);
typedef int  (OPT_CALLCONV *optGetEnumValue_t) (optHandle_t popt, int ANr, int AOrd, int *AValInt, char *AValStr);
OPT_FUNCPTR(optGetEnumValue);
typedef int  (OPT_CALLCONV *optGetStr2Nr_t) (optHandle_t popt, int ANr, char *ASVal);
OPT_FUNCPTR(optGetStr2Nr);
typedef int  (OPT_CALLCONV *optSetStrNr_t) (optHandle_t popt, int ANr, const char *ASVal);
OPT_FUNCPTR(optSetStrNr);
typedef int  (OPT_CALLCONV *optSetStr2Nr_t) (optHandle_t popt, int ANr, const char *ASVal);
OPT_FUNCPTR(optSetStr2Nr);
typedef int  (OPT_CALLCONV *optGetDblNr_t) (optHandle_t popt, int ANr, double *ADVal);
OPT_FUNCPTR(optGetDblNr);
typedef int  (OPT_CALLCONV *optGetDbl2Nr_t) (optHandle_t popt, int ANr, double *ADVal);
OPT_FUNCPTR(optGetDbl2Nr);
typedef int  (OPT_CALLCONV *optSetDblNr_t) (optHandle_t popt, int ANr, double ADVal);
OPT_FUNCPTR(optSetDblNr);
typedef int  (OPT_CALLCONV *optSetDbl2Nr_t) (optHandle_t popt, int ANr, double ADVal);
OPT_FUNCPTR(optSetDbl2Nr);
typedef int  (OPT_CALLCONV *optGetValStr_t) (optHandle_t popt, const char *AName, char *ASVal);
OPT_FUNCPTR(optGetValStr);
typedef int  (OPT_CALLCONV *optGetVal2Str_t) (optHandle_t popt, const char *AName, char *ASVal);
OPT_FUNCPTR(optGetVal2Str);
typedef int  (OPT_CALLCONV *optGetNameNr_t) (optHandle_t popt, int ANr, char *ASName);
OPT_FUNCPTR(optGetNameNr);
typedef int  (OPT_CALLCONV *optGetDefinedNr_t) (optHandle_t popt, int ANr, int *AIVal);
OPT_FUNCPTR(optGetDefinedNr);
typedef int  (OPT_CALLCONV *optGetHelpNr_t) (optHandle_t popt, int ANr, char *ASOpt, char *ASHelp);
OPT_FUNCPTR(optGetHelpNr);
typedef int  (OPT_CALLCONV *optGetGroupNr_t) (optHandle_t popt, int ANr, char *AName, int *AGroup, int *AHc, char *AHelp);
OPT_FUNCPTR(optGetGroupNr);
typedef int  (OPT_CALLCONV *optGetGroupGrpNr_t) (optHandle_t popt, int AGroup);
OPT_FUNCPTR(optGetGroupGrpNr);
typedef int  (OPT_CALLCONV *optGetOptGroupNr_t) (optHandle_t popt, int ANr);
OPT_FUNCPTR(optGetOptGroupNr);
typedef int  (OPT_CALLCONV *optGetDotOptNr_t) (optHandle_t popt, int ANr, char *VEName, int *AObjNr, int *ADim, double *AValue);
OPT_FUNCPTR(optGetDotOptNr);
typedef int  (OPT_CALLCONV *optGetDotOptUel_t) (optHandle_t popt, int ANr, int ADim, char *AUEL);
OPT_FUNCPTR(optGetDotOptUel);
typedef int  (OPT_CALLCONV *optGetVarEquMapNr_t) (optHandle_t popt, int maptype, int ANr, char *EquName, char *VarName, int *EquDim, int *VarDim, int *AValue);
OPT_FUNCPTR(optGetVarEquMapNr);
typedef int  (OPT_CALLCONV *optGetEquVarEquMapNr_t) (optHandle_t popt, int maptype, int ANr, int ADim, char *AIndex);
OPT_FUNCPTR(optGetEquVarEquMapNr);
typedef int  (OPT_CALLCONV *optGetVarVarEquMapNr_t) (optHandle_t popt, int maptype, int ANr, int ADim, char *AIndex);
OPT_FUNCPTR(optGetVarVarEquMapNr);
typedef int  (OPT_CALLCONV *optVarEquMapCount_t) (optHandle_t popt, int maptype, int *ANrErrors);
OPT_FUNCPTR(optVarEquMapCount);
typedef int  (OPT_CALLCONV *optGetIndicatorNr_t) (optHandle_t popt, int ANr, char *EquName, char *VarName, int *EquDim, int *VarDim, int *AValue);
OPT_FUNCPTR(optGetIndicatorNr);
typedef int  (OPT_CALLCONV *optGetEquIndicatorNr_t) (optHandle_t popt, int ANr, int ADim, char *AIndex);
OPT_FUNCPTR(optGetEquIndicatorNr);
typedef int  (OPT_CALLCONV *optGetVarIndicatorNr_t) (optHandle_t popt, int ANr, int ADim, char *AIndex);
OPT_FUNCPTR(optGetVarIndicatorNr);
typedef int  (OPT_CALLCONV *optIndicatorCount_t) (optHandle_t popt, int *ANrErrors);
OPT_FUNCPTR(optIndicatorCount);
typedef int  (OPT_CALLCONV *optDotOptCount_t) (optHandle_t popt, int *ANrErrors);
OPT_FUNCPTR(optDotOptCount);
typedef int  (OPT_CALLCONV *optSetRefNr_t) (optHandle_t popt, int ANr, int ARefNr);
OPT_FUNCPTR(optSetRefNr);
typedef int  (OPT_CALLCONV *optSetRefNrStr_t) (optHandle_t popt, const char *AOpt, int ARefNr);
OPT_FUNCPTR(optSetRefNrStr);
typedef int  (OPT_CALLCONV *optGetConstName_t) (optHandle_t popt, int cgroup, int cindex, char *cname);
OPT_FUNCPTR(optGetConstName);
typedef int  (OPT_CALLCONV *optGetTypeName_t) (optHandle_t popt, int TNr, char *sTName);
OPT_FUNCPTR(optGetTypeName);
typedef int  (OPT_CALLCONV *optLookUp_t) (optHandle_t popt, const char *AOpt);
OPT_FUNCPTR(optLookUp);
typedef void  (OPT_CALLCONV *optReadFromPChar_t) (optHandle_t popt, char *p);
OPT_FUNCPTR(optReadFromPChar);
typedef void  (OPT_CALLCONV *optReadFromCmdLine_t) (optHandle_t popt, char *p);
OPT_FUNCPTR(optReadFromCmdLine);
typedef void  (OPT_CALLCONV *optReadFromCmdArgs_t) (optHandle_t popt, TArgvCB_t cb);
OPT_FUNCPTR(optReadFromCmdArgs);
typedef int  (OPT_CALLCONV *optGetNameOpt_t) (optHandle_t popt, const char *ASVal, char *solver, int *opt);
OPT_FUNCPTR(optGetNameOpt);
typedef int  (OPT_CALLCONV *optResetStr_t) (optHandle_t popt, const char *AName);
OPT_FUNCPTR(optResetStr);
typedef int  (OPT_CALLCONV *optGetDefinedStr_t) (optHandle_t popt, const char *AName);
OPT_FUNCPTR(optGetDefinedStr);
typedef int  (OPT_CALLCONV *optGetIntStr_t) (optHandle_t popt, const char *AName);
OPT_FUNCPTR(optGetIntStr);
typedef double  (OPT_CALLCONV *optGetDblStr_t) (optHandle_t popt, const char *AName);
OPT_FUNCPTR(optGetDblStr);
typedef char * (OPT_CALLCONV *optGetStrStr_t) (optHandle_t popt, const char *AName, char *buf);
OPT_FUNCPTR(optGetStrStr);
typedef void  (OPT_CALLCONV *optSetIntStr_t) (optHandle_t popt, const char *AName, int AIVal);
OPT_FUNCPTR(optSetIntStr);
typedef void  (OPT_CALLCONV *optSetDblStr_t) (optHandle_t popt, const char *AName, double ADVal);
OPT_FUNCPTR(optSetDblStr);
typedef void  (OPT_CALLCONV *optSetStrStr_t) (optHandle_t popt, const char *AName, const char *ASVal);
OPT_FUNCPTR(optSetStrStr);
typedef int  (OPT_CALLCONV *optIsDeprecated_t) (optHandle_t popt, const char *AName);
OPT_FUNCPTR(optIsDeprecated);
typedef int  (OPT_CALLCONV *optCount_t) (optHandle_t popt);
OPT_FUNCPTR(optCount);
typedef int  (OPT_CALLCONV *optMessageCount_t) (optHandle_t popt);
OPT_FUNCPTR(optMessageCount);
typedef int  (OPT_CALLCONV *optGroupCount_t) (optHandle_t popt);
OPT_FUNCPTR(optGroupCount);
typedef int  (OPT_CALLCONV *optRecentEnabled_t) (optHandle_t popt);
OPT_FUNCPTR(optRecentEnabled);
typedef void (OPT_CALLCONV *optRecentEnabledSet_t) (optHandle_t popt, const int x);
OPT_FUNCPTR(optRecentEnabledSet);
typedef char * (OPT_CALLCONV *optSeparator_t) (optHandle_t popt, char *buf);
OPT_FUNCPTR(optSeparator);
typedef char * (OPT_CALLCONV *optStringQuote_t) (optHandle_t popt, char *buf);
OPT_FUNCPTR(optStringQuote);
#if defined(__cplusplus)
}
#endif
#endif /* #if ! defined(_OPTCC_H_) */
